# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from notifications_server_connector.models.send_notification_request import SendNotificationRequest  # noqa: E501

class TestSendNotificationRequest(unittest.TestCase):
    """SendNotificationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SendNotificationRequest:
        """Test SendNotificationRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SendNotificationRequest`
        """
        model = SendNotificationRequest()  # noqa: E501
        if include_optional:
            return SendNotificationRequest(
                source_type_id = None,
                source_id = 56,
                portal_id = 56,
                portal_member_id = 56,
                title = '',
                message = '',
                is_anonymous = True,
                parent_id = 56,
                parent_name = '',
                created_at = 56,
                fcm_topic = '',
                notification_receivers = [
                    56
                    ],
                args = notifications_server_connector.models.args.Args(),
                extra_email_receivers = [
                    ''
                    ],
                subject_override = '',
                body_override = ''
            )
        else:
            return SendNotificationRequest(
                source_type_id = None,
                source_id = 56,
                portal_id = 56,
                portal_member_id = 56,
                title = '',
                message = '',
        )
        """

    def testSendNotificationRequest(self):
        """Test SendNotificationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
